# Manifestoo Core

[![Github-CI][github-ci]][github-link]
[![Coverage Status][codecov-badge]][codecov-link]
[![PyPI][pypi-badge]][pypi-link]

<!--- shortdesc-begin -->

A library to reason about [Odoo](https://odoo.com) addons manifests.

<!--- shortdesc-end -->

## Installation

<!--- install-begin -->

```console
pip install manifestoo-core
```

<!--- install-end -->

## Features

<!--- features-begin -->

`manifestoo_core` provides the following features:

* Detect the Odoo series from an addon version.
* Information about core Odoo CE and EE addons for each Odoo version.
* Convert Odoo manifest metadata to Python Packaging Metadata.

Read the [documentation](https://manifestoo-core.readthedocs.io/) for more information.

```{warning}
Any part of the library that is not documented may change without notice.
```

<!--- features-end -->

[github-ci]: https://github.com/sbidoul/manifestoo-core/actions/workflows/ci.yml/badge.svg
[github-link]: https://github.com/sbidoul/manifestoo-core
[codecov-badge]: https://codecov.io/gh/sbidoul/manifestoo-core/branch/master/graph/badge.svg
[codecov-link]: https://codecov.io/gh/sbidoul/manifestoo-core
[pypi-badge]: https://img.shields.io/pypi/v/manifestoo-core.svg
[pypi-link]: https://pypi.org/project/manifestoo-core
